@@ -56,7 +56,7 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
     sig_project_closed = Signal(object)
     sig_new_file = Signal(str)
 
-    def __init__(self, parent=None, testing=False):
+    def __init__(self, parent=None):
         ProjectExplorerWidget.__init__(self, parent=parent,
                     name_filters=self.get_option('name_filters'),
                     show_all=self.get_option('show_all'),
@@ -67,15 +67,8 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
         self.current_active_project = None
         self.latest_project = None
 
-        self.editor = None
-        self.workingdirectory = None
-
-        # For testing
-        self.testing = testing
-
         # Initialize plugin
-        if not self.testing:
-            self.initialize_plugin()
+        self.initialize_plugin()
         self.setup_project(self.get_active_project_path())
 
     #------ SpyderPluginWidget API ---------------------------------------------
@@ -103,7 +96,7 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
                                     triggered=self.close_project)
         self.delete_project_action = create_action(self,
                                     _("Delete Project"),
-                                    triggered=self.delete_project)
+                                    triggered=self._delete_project)
         self.clear_recent_projects_action =\
             create_action(self, _("Clear this list"),
                           triggered=self.clear_recent_projects)
@@ -113,54 +106,53 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
         self.recent_project_menu = QMenu(_("Recent Projects"), self)
         explorer_action = self.toggle_view_action
 
-        self.main.projects_menu_actions += [self.new_project_action,
-                                            MENU_SEPARATOR,
-                                            self.open_project_action,
-                                            self.close_project_action,
-                                            self.delete_project_action,
-                                            MENU_SEPARATOR,
-                                            self.recent_project_menu,
-                                            explorer_action]
+        if self.main is not None:
+            self.main.projects_menu_actions += [self.new_project_action,
+                                                MENU_SEPARATOR,
+                                                self.open_project_action,
+                                                self.close_project_action,
+                                                self.delete_project_action,
+                                                MENU_SEPARATOR,
+                                                self.recent_project_menu,
+                                                explorer_action]
 
         self.setup_menu_actions()
         return []
 
     def register_plugin(self):
         """Register plugin in Spyder's main window"""
-        self.editor = self.main.editor
-        self.workingdirectory = self.main.workingdirectory
-
         self.main.pythonpath_changed()
         self.main.restore_scrollbar_position.connect(
                                                self.restore_scrollbar_position)
         self.sig_pythonpath_changed.connect(self.main.pythonpath_changed)
-        self.create_module.connect(self.editor.new)
-        self.edit.connect(self.editor.load)
-        self.removed.connect(self.editor.removed)
-        self.removed_tree.connect(self.editor.removed_tree)
-        self.renamed.connect(self.editor.renamed)
-        self.renamed_tree.connect(self.editor.renamed_tree)
-        self.editor.set_projects(self)
+        self.create_module.connect(self.main.editor.new)
+        self.edit.connect(self.main.editor.load)
+        self.removed.connect(self.main.editor.removed)
+        self.removed_tree.connect(self.main.editor.removed_tree)
+        self.renamed.connect(self.main.editor.renamed)
+        self.renamed_tree.connect(self.main.editor.renamed_tree)
+        self.main.editor.set_projects(self)
         self.main.add_dockwidget(self)
 
         self.sig_open_file.connect(self.main.open_file)
 
-        self.sig_new_file.connect(lambda x: self.editor.new(text=x))
+        self.sig_new_file.connect(lambda x: self.main.editor.new(text=x))
 
         # New project connections. Order matters!
         self.sig_project_loaded.connect(
-            lambda v: self.workingdirectory.chdir(v))
+            lambda v: self.main.workingdirectory.chdir(v))
         self.sig_project_loaded.connect(
             lambda v: self.main.set_window_title())
         self.sig_project_loaded.connect(
-            lambda v: self.editor.setup_open_files())
+            lambda v: self.main.editor.setup_open_files())
         self.sig_project_loaded.connect(self.update_explorer)
         self.sig_project_closed[object].connect(
-            lambda v: self.workingdirectory.chdir(self.get_last_working_dir()))
+            lambda v: self.main.workingdirectory.chdir(
+                self.get_last_working_dir()))
         self.sig_project_closed.connect(
             lambda v: self.main.set_window_title())
         self.sig_project_closed.connect(
-            lambda v: self.editor.setup_open_files())
+            lambda v: self.main.editor.setup_open_files())
         self.recent_project_menu.aboutToShow.connect(self.setup_menu_actions)
 
     def refresh_plugin(self):
@@ -173,7 +165,21 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
         self.closing_widget()
         return True
 
-    #------ Public API ---------------------------------------------------------
+    def switch_to_plugin(self):
+        """Switch to plugin."""
+        # Unmaxizime currently maximized plugin
+        if (self.main.last_plugin is not None and
+                self.main.last_plugin.ismaximized and
+                self.main.last_plugin is not self):
+            self.main.maximize_dockwidget()
+
+        # Show plugin only if it was already visible
+        if self.get_option('visible_if_project_open'):
+            if not self.toggle_view_action.isChecked():
+                self.toggle_view_action.setChecked(True)
+            self.visibility_changed(True)
+
+    # ------ Public API -------------------------------------------------------
     def setup_menu_actions(self):
         """Setup and update the menu actions."""
         self.recent_project_menu.clear()
@@ -182,10 +188,13 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
             for project in self.recent_projects:
                 if self.is_valid_project(project):
                     name = project.replace(get_home_dir(), '~')
-                    action = create_action(self,
+                    action = create_action(
+                        self,
                         name,
-                        icon = ima.icon('project'),
-                        triggered=lambda v, path=project: self.open_project(path=path))
+                        icon=ima.icon('project'),
+                        triggered=(
+                            lambda _, p=project: self.open_project(path=p))
+                        )
                     self.recent_projects_actions.append(action)
                 else:
                     self.recent_projects.remove(project)
@@ -225,13 +234,14 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
     @Slot()
     def create_new_project(self):
         """Create new project"""
+        self.switch_to_plugin()
         active_project = self.current_active_project
         dlg = ProjectDialog(self)
         dlg.sig_project_creation_requested.connect(self._create_project)
         dlg.sig_project_creation_requested.connect(self.sig_project_created)
         if dlg.exec_():
-            pass
-            if active_project is None:
+            if (active_project is None
+                    and self.get_option('visible_if_project_open')):
                 self.show_explorer()
             self.sig_pythonpath_changed.emit()
             self.restart_consoles()
@@ -245,6 +255,7 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
     def open_project(self, path=None, restart_consoles=True,
                      save_previous_files=True):
         """Open the project located in `path`"""
+        self.switch_to_plugin()
         if path is None:
             basedir = get_home_dir()
             path = getexistingdirectory(parent=self,
@@ -263,22 +274,24 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
 
         # A project was not open before
         if self.current_active_project is None:
-            if save_previous_files and self.editor is not None:
-                self.editor.save_open_files()
-            if self.editor is not None:
-                self.editor.set_option('last_working_dir', getcwd_or_home())
-            self.show_explorer()
+            if save_previous_files and self.main.editor is not None:
+                self.main.editor.save_open_files()
+            if self.main.editor is not None:
+                self.main.editor.set_option('last_working_dir',
+                                            getcwd_or_home())
+            if self.get_option('visible_if_project_open'):
+                self.show_explorer()
         else:
             # We are switching projects
-            if self.editor is not None:
-                self.set_project_filenames(self.editor.get_open_filenames())
+            if self.main.editor is not None:
+                self.set_project_filenames(
+                    self.main.editor.get_open_filenames())
 
         self.current_active_project = EmptyProject(path)
         self.latest_project = EmptyProject(path)
         self.set_option('current_project_path', self.get_active_project_path())
 
-        if not self.testing:
-            self.setup_menu_actions()
+        self.setup_menu_actions()
         self.sig_project_loaded.emit(path)
         self.sig_pythonpath_changed.emit()
 
@@ -291,24 +304,32 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
         project
         """
         if self.current_active_project:
+            self.switch_to_plugin()
             path = self.current_active_project.root_path
             self.current_active_project = None
             self.set_option('current_project_path', None)
-
-            if not self.testing:
-                self.setup_menu_actions()
+            self.setup_menu_actions()
 
             self.sig_project_closed.emit(path)
             self.sig_pythonpath_changed.emit()
 
             if self.dockwidget is not None:
+                self.set_option('visible_if_project_open',
+                                self.dockwidget.isVisible())
                 self.dockwidget.close()
 
             self.clear()
             self.restart_consoles()
 
-            if self.editor is not None:
-                self.set_project_filenames(self.editor.get_open_filenames())
+            if self.main.editor is not None:
+                self.set_project_filenames(
+                    self.main.editor.get_open_filenames())
+
+    def _delete_project(self):
+        """Delete current project."""
+        if self.current_active_project:
+            self.switch_to_plugin()
+            self.delete_project()
 
     def clear_recent_projects(self):
         """Clear the list of recent projects"""
@@ -371,15 +392,22 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
 
     def get_last_working_dir(self):
         """Get the path of the last working directory"""
-        return self.editor.get_option('last_working_dir',
-                                      default=getcwd_or_home())
+        return self.main.editor.get_option('last_working_dir',
+                                           default=getcwd_or_home())
 
     def save_config(self):
-        """Save configuration: opened projects & tree widget state"""
+        """
+        Save configuration: opened projects & tree widget state.
+
+        Also save whether dock widget is visible if a project is open.
+        """
         self.set_option('recent_projects', self.recent_projects)
         self.set_option('expanded_state', self.treewidget.get_expanded_state())
         self.set_option('scrollbar_position',
                         self.treewidget.get_scrollbar_position())
+        if self.current_active_project and self.dockwidget:
+            self.set_option('visible_if_project_open',
+                            self.dockwidget.isVisible())
 
     def load_config(self):
         """Load configuration: opened projects & tree widget state"""
@@ -412,7 +440,7 @@ class Projects(ProjectExplorerWidget, SpyderPluginMixin):
 
     def restart_consoles(self):
         """Restart consoles when closing, opening and switching projects"""
-        if not self.testing and self.main.ipyconsole is not None:
+        if self.main.ipyconsole is not None:
             self.main.ipyconsole.restart()
 
     def is_valid_project(self, path):
