@@ -1,9 +1,11 @@
 # -*- coding: utf-8 -*-
 """
-Spyder License Agreement (MIT License)
---------------------------------------
+MIT License
+===========
 
-Copyright (c) Spyder Project Contributors
+The spyder/images dir and some source files under other terms (see NOTICE.txt).
+
+Copyright (c) 2009- Spyder Project Contributors and others (see AUTHORS.txt)
 
 Permission is hereby granted, free of charge, to any person
 obtaining a copy of this software and associated documentation
@@ -27,14 +29,15 @@ FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 OTHER DEALINGS IN THE SOFTWARE.
 """
 
-version_info = (3, 3, 0)
+version_info = (3, 3, 3)
 
 __version__ = '.'.join(map(str, version_info))
 __license__ = __doc__
 __project_url__ = 'https://github.com/spyder-ide/spyder'
-__forum_url__   = 'http://groups.google.com/group/spyderlib'
+__forum_url__   = 'https://groups.google.com/group/spyderlib'
 __trouble_url__ = __project_url__ + '/wiki/Troubleshooting-Guide-and-FAQ'
 __trouble_url_short__ = 'https://tinyurl.com/SpyderHelp'
+__website_url__ = 'https://www.spyder-ide.org/'
 
 # Dear (Debian, RPM, ...) package makers, please feel free to customize the
 # following path to module's data (images) and translations:
