@@ -1,16 +1,24 @@
 # -*- coding: utf-8 -*-
+# -----------------------------------------------------------------------------
+# Copyright (c) 2011-2012 Lambda Foundry, Inc. and PyData Development Team
+# Copyright (c) 2013 Jev Kuznetsov and contributors
+# Copyright (c) 2014- Spyder Project Contributors
 #
-# Copyright © Spyder Project Contributors
-# Licensed under the terms of the New BSD License
-#
-# DataFrameModel is based on the class ArrayModel from array editor
-# and the class DataFrameModel from the pandas project.
-# Present in pandas.sandbox.qtpandas in v0.13.1
-# Copyright (c) 2011-2012, Lambda Foundry, Inc.
-# and PyData Development Team All rights reserved
+# Distributed under the terms of the New BSD License
+# (BSD 3-clause; see NOTICE.txt in the Spyder root directory for details).
+# -----------------------------------------------------------------------------
 
 """
-Pandas DataFrame Editor Dialog
+Pandas DataFrame Editor Dialog.
+
+DataFrameModel is based on the class ArrayModel from array editor
+and the class DataFrameModel from the pandas project.
+Present in pandas.sandbox.qtpandas in v0.13.1.
+
+Originally based on pandas/sandbox/qtpandas.py of the
+`pandas project <https://github.com/pandas-dev/pandas>`_.
+The current version is qtpandas/models/DataFrameModel.py of the
+`QtPandas project <https://github.com/draperjames/qtpandas>`_.
 """
 
 # Third party imports
@@ -97,6 +105,7 @@ class DataFrameModel(QAbstractTableModel):
         self.df_header = dataFrame.columns.tolist()
         self._format = format
         self.complex_intran = None
+        self.display_error_idxs = []
         
         self.total_rows = self.df.shape[0]
         self.total_cols = self.df.shape[1]
@@ -298,11 +307,19 @@ class DataFrameModel(QAbstractTableModel):
                     # what is shown by Spyder
                     return value
                 else:
-                    return to_qvariant(to_text_string(value))
+                    try:
+                        return to_qvariant(to_text_string(value))
+                    except Exception:
+                        self.display_error_idxs.append(index)
+                        return u'Display Error!'
         elif role == Qt.BackgroundColorRole:
             return to_qvariant(self.get_bgcolor(index))
         elif role == Qt.FontRole:
             return to_qvariant(get_font(font_size_delta=DEFAULT_SMALL_DELTA))
+        elif role == Qt.ToolTipRole:
+            if index in self.display_error_idxs:
+                return _("It is not possible to display this value because\n"
+                         "an error ocurred while trying to do it")
         return to_qvariant()
 
     def sort(self, column, order=Qt.AscendingOrder):
@@ -357,6 +374,8 @@ class DataFrameModel(QAbstractTableModel):
         column = index.column()
         row = index.row()
 
+        if index in self.display_error_idxs:
+            return False
         if change_type is not None:
             try:
                 value = self.data(index, role=Qt.DisplayRole)
@@ -446,7 +465,7 @@ class DataFrameModel(QAbstractTableModel):
 class FrozenTableView(QTableView):
     """This class implements a table with its first column frozen
     For more information please see:
-    http://doc.qt.io/qt-5/qtwidgets-itemviews-frozencolumn-example.html"""
+    https://doc.qt.io/qt-5/qtwidgets-itemviews-frozencolumn-example.html"""
     def __init__(self, parent):
         """Constructor."""
         QTableView.__init__(self, parent)
